@@ -1,16 +1,16 @@
 # frozen_string_literal: true
 
 module ActionMailer
-  # Returns the currently loaded version of Action Mailer as a <tt>Gem::Version</tt>.
+  # Returns the currently loaded version of Action Mailer as a +Gem::Version+.
   def self.gem_version
     Gem::Version.new VERSION::STRING
   end
 
   module VERSION
-    MAJOR = 7
+    MAJOR = 8
     MINOR = 0
-    TINY  = 8
-    PRE   = "7"
+    TINY  = 2
+    PRE   = nil
 
     STRING = [MAJOR, MINOR, TINY, PRE].compact.join(".")
   end
